@@ -17,6 +17,7 @@ def _get_kwargs(
     include_header: Union[Unset, None, str] = UNSET,
     queue_limit: Union[Unset, None, str] = UNSET,
     job_id: Union[Unset, None, str] = UNSET,
+    skip_preprocessor: Union[Unset, None, bool] = UNSET,
 ) -> Dict[str, Any]:
     pass
 
@@ -27,6 +28,8 @@ def _get_kwargs(
 
     params["job_id"] = job_id
 
+    params["skip_preprocessor"] = skip_preprocessor
+
     params = {k: v for k, v in params.items() if v is not UNSET and v is not None}
 
     json_json_body = json_body.to_dict()
@@ -69,6 +72,7 @@ def sync_detailed(
     include_header: Union[Unset, None, str] = UNSET,
     queue_limit: Union[Unset, None, str] = UNSET,
     job_id: Union[Unset, None, str] = UNSET,
+    skip_preprocessor: Union[Unset, None, bool] = UNSET,
 ) -> Response[Any]:
     """run flow by path and wait until completion
 
@@ -78,6 +82,7 @@ def sync_detailed(
         include_header (Union[Unset, None, str]):
         queue_limit (Union[Unset, None, str]):
         job_id (Union[Unset, None, str]):
+        skip_preprocessor (Union[Unset, None, bool]):
         json_body (RunWaitResultFlowByPathJsonBody): The arguments to pass to the script or flow
 
     Raises:
@@ -95,6 +100,7 @@ def sync_detailed(
         include_header=include_header,
         queue_limit=queue_limit,
         job_id=job_id,
+        skip_preprocessor=skip_preprocessor,
     )
 
     response = client.get_httpx_client().request(
@@ -113,6 +119,7 @@ async def asyncio_detailed(
     include_header: Union[Unset, None, str] = UNSET,
     queue_limit: Union[Unset, None, str] = UNSET,
     job_id: Union[Unset, None, str] = UNSET,
+    skip_preprocessor: Union[Unset, None, bool] = UNSET,
 ) -> Response[Any]:
     """run flow by path and wait until completion
 
@@ -122,6 +129,7 @@ async def asyncio_detailed(
         include_header (Union[Unset, None, str]):
         queue_limit (Union[Unset, None, str]):
         job_id (Union[Unset, None, str]):
+        skip_preprocessor (Union[Unset, None, bool]):
         json_body (RunWaitResultFlowByPathJsonBody): The arguments to pass to the script or flow
 
     Raises:
@@ -139,6 +147,7 @@ async def asyncio_detailed(
         include_header=include_header,
         queue_limit=queue_limit,
         job_id=job_id,
+        skip_preprocessor=skip_preprocessor,
     )
 
     response = await client.get_async_httpx_client().request(**kwargs)
