@@ -13,17 +13,20 @@ class CreateFolderJsonBody:
     """
     Attributes:
         name (str):
+        summary (Union[Unset, str]):
         owners (Union[Unset, List[str]]):
         extra_perms (Union[Unset, Any]):
     """
 
     name: str
+    summary: Union[Unset, str] = UNSET
     owners: Union[Unset, List[str]] = UNSET
     extra_perms: Union[Unset, Any] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
         name = self.name
+        summary = self.summary
         owners: Union[Unset, List[str]] = UNSET
         if not isinstance(self.owners, Unset):
             owners = self.owners
@@ -37,6 +40,8 @@ class CreateFolderJsonBody:
                 "name": name,
             }
         )
+        if summary is not UNSET:
+            field_dict["summary"] = summary
         if owners is not UNSET:
             field_dict["owners"] = owners
         if extra_perms is not UNSET:
@@ -49,12 +54,15 @@ class CreateFolderJsonBody:
         d = src_dict.copy()
         name = d.pop("name")
 
+        summary = d.pop("summary", UNSET)
+
         owners = cast(List[str], d.pop("owners", UNSET))
 
         extra_perms = d.pop("extra_perms", UNSET)
 
         create_folder_json_body = cls(
             name=name,
+            summary=summary,
             owners=owners,
             extra_perms=extra_perms,
         )
