@@ -1,7 +1,11 @@
-from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, cast
+import datetime
+from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union, cast
 
 from attrs import define as _attrs_define
 from attrs import field as _attrs_field
+from dateutil.parser import isoparse
+
+from ..types import UNSET, Unset
 
 if TYPE_CHECKING:
     from ..models.get_folder_response_200_extra_perms import GetFolderResponse200ExtraPerms
@@ -17,11 +21,17 @@ class GetFolderResponse200:
         name (str):
         owners (List[str]):
         extra_perms (GetFolderResponse200ExtraPerms):
+        summary (Union[Unset, str]):
+        created_by (Union[Unset, str]):
+        edited_at (Union[Unset, datetime.datetime]):
     """
 
     name: str
     owners: List[str]
     extra_perms: "GetFolderResponse200ExtraPerms"
+    summary: Union[Unset, str] = UNSET
+    created_by: Union[Unset, str] = UNSET
+    edited_at: Union[Unset, datetime.datetime] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -30,6 +40,12 @@ class GetFolderResponse200:
 
         extra_perms = self.extra_perms.to_dict()
 
+        summary = self.summary
+        created_by = self.created_by
+        edited_at: Union[Unset, str] = UNSET
+        if not isinstance(self.edited_at, Unset):
+            edited_at = self.edited_at.isoformat()
+
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
         field_dict.update(
@@ -39,6 +55,12 @@ class GetFolderResponse200:
                 "extra_perms": extra_perms,
             }
         )
+        if summary is not UNSET:
+            field_dict["summary"] = summary
+        if created_by is not UNSET:
+            field_dict["created_by"] = created_by
+        if edited_at is not UNSET:
+            field_dict["edited_at"] = edited_at
 
         return field_dict
 
@@ -53,10 +75,24 @@ class GetFolderResponse200:
 
         extra_perms = GetFolderResponse200ExtraPerms.from_dict(d.pop("extra_perms"))
 
+        summary = d.pop("summary", UNSET)
+
+        created_by = d.pop("created_by", UNSET)
+
+        _edited_at = d.pop("edited_at", UNSET)
+        edited_at: Union[Unset, datetime.datetime]
+        if isinstance(_edited_at, Unset):
+            edited_at = UNSET
+        else:
+            edited_at = isoparse(_edited_at)
+
         get_folder_response_200 = cls(
             name=name,
             owners=owners,
             extra_perms=extra_perms,
+            summary=summary,
+            created_by=created_by,
+            edited_at=edited_at,
         )
 
         get_folder_response_200.additional_properties = d
