@@ -38,7 +38,8 @@ class ListKafkaTriggersResponse200Item:
         last_server_ping (Union[Unset, datetime.datetime]):
         error (Union[Unset, str]):
         error_handler_path (Union[Unset, str]):
-        error_handler_args (Union[Unset, ListKafkaTriggersResponse200ItemErrorHandlerArgs]):
+        error_handler_args (Union[Unset, ListKafkaTriggersResponse200ItemErrorHandlerArgs]): The arguments to pass to
+            the script or flow
         retry (Union[Unset, ListKafkaTriggersResponse200ItemRetry]):
     """
 
